@@ -659,9 +659,9 @@ def maskrcnn_process_video(
     frame_count = 0
     # Read until video is completed
     while cap.isOpened():
+        
         # Capture frame-by-frame
         ret, frame = cap.read()
-        # print(frame.shape)
         if ret == True:
 
             # resize frame to match output_shape
@@ -675,7 +675,7 @@ def maskrcnn_process_video(
             processed_imgs = maskrcnn_process_images(imgs, preds, class_map, config)
 
             if frame_count == 0 and show_first_frame:
-                cv_utility.show(processed_imgs)
+                show(processed_imgs)
 
             ndarr_img = processed_imgs[0].permute(1, 2, 0).cpu().numpy()
             ndarr_img = cv2.cvtColor(ndarr_img, cv2.COLOR_BGR2RGB)
